@@ -34,7 +34,8 @@
 
 gboolean desktop_file_validate (const char *filename,
 				gboolean    warn_kde,
-				gboolean    no_warn_deprecated);
+				gboolean    no_warn_deprecated,
+				gboolean    no_hints);
 gboolean desktop_file_fixup    (GKeyFile   *keyfile,
                                 const char *filename);
 
